# == Class: stackdriver
#
# This class installs and configures the stackdriver agent (stackdriver.com)
# 
# Parameters:
#
#   [*stackdriver_config*]
#     - The agent configuration file
#
#   [*stackdriver_api_key*]
#     - The stackdriver api key (see https://app.stackdriver.com/settings/)
#   
#   [*stackdriver_package*]
#     - The name of the package for your os family
#
#   [*stackdriver_version*]
#     - Version of the agent to install

class stackdriver(
    $stackdriver_config = $stackdriver::params::stackdriver_config,
    $stackdriver_api_key = $stackdriver::params::stackdriver_api_key,
    $stackdriver_package = $stackdriver::params::stackdriver_package,
    $stackdriver_version = $stackdriver::params::version
) inherits stackdriver::params {
    class { "stackdriver::package::${::osfamily}": }

    file { $stackdriver_config:
        content => template('stackdriver/config.erb')
    }

    service { 'stackdriver-agent':
        ensure => running,
        subscribe => File[$stackdriver_config],
        require => Package[$stackdriver_package]
    }
}

include stackdriver
